@@ -42,11 +42,11 @@ class WP_Press_This {
 	public function site_settings() {
 		return array(
 			/**
-			 * Filter whether or not Press This should redirect the user in the parent window upon save.
+			 * Filters whether or not Press This should redirect the user in the parent window upon save.
 			 *
 			 * @since 4.2.0
 			 *
-			 * @param bool false Whether to redirect in parent window or not. Default false.
+			 * @param bool $redirect Whether to redirect in parent window or not. Default false.
 			 */
 			'redirInParent' => apply_filters( 'press_this_redirect_in_parent', false ),
 		);
@@ -91,12 +91,12 @@ class WP_Press_This {
 			}
 		}
 
-		// Edxpected slashed
+		// Expected slashed
 		return wp_slash( $content );
 	}
 
 	/**
-	 * AJAX handler for saving the post as draft or published.
+	 * Ajax handler for saving the post as draft or published.
 	 *
 	 * @since 4.2.0
 	 * @access public
@@ -112,7 +112,7 @@ class WP_Press_This {
 			wp_send_json_error( array( 'errorMessage' => __( 'Invalid post.' ) ) );
 		}
 
-		$post = array(
+		$post_data = array(
 			'ID'            => $post_id,
 			'post_title'    => ( ! empty( $_POST['post_title'] ) ) ? sanitize_text_field( trim( $_POST['post_title'] ) ) : '',
 			'post_content'  => ( ! empty( $_POST['post_content'] ) ) ? trim( $_POST['post_content'] ) : '',
@@ -143,23 +143,34 @@ class WP_Press_This {
 		// Toggle status to pending if user cannot actually publish
 		if ( ! empty( $_POST['post_status'] ) && 'publish' === $_POST['post_status'] ) {
 			if ( current_user_can( 'publish_posts' ) ) {
-				$post['post_status'] = 'publish';
+				$post_data['post_status'] = 'publish';
 			} else {
-				$post['post_status'] = 'pending';
+				$post_data['post_status'] = 'pending';
 			}
 		}
 
-		$post['post_content'] = $this->side_load_images( $post_id, $post['post_content'] );
+		$post_data['post_content'] = $this->side_load_images( $post_id, $post_data['post_content'] );
 
-		$updated = wp_update_post( $post, true );
+		/**
+		 * Filters the post data of a Press This post before saving/updating.
+		 *
+		 * The {@see 'side_load_images'} action has already run at this point.
+		 *
+		 * @since 4.5.0
+		 *
+		 * @param array $post_data The post data.
+		 */
+		$post_data = apply_filters( 'press_this_save_post', $post_data );
+
+		$updated = wp_update_post( $post_data, true );
 
 		if ( is_wp_error( $updated ) ) {
 			wp_send_json_error( array( 'errorMessage' => $updated->get_error_message() ) );
 		} else {
-			if ( isset( $post['post_format'] ) ) {
-				if ( current_theme_supports( 'post-formats', $post['post_format'] ) ) {
-					set_post_format( $post_id, $post['post_format'] );
-				} elseif ( $post['post_format'] ) {
+			if ( isset( $post_data['post_format'] ) ) {
+				if ( current_theme_supports( 'post-formats', $post_data['post_format'] ) ) {
+					set_post_format( $post_id, $post_data['post_format'] );
+				} elseif ( $post_data['post_format'] ) {
 					set_post_format( $post_id, false );
 				}
 			}
@@ -176,7 +187,7 @@ class WP_Press_This {
 			}
 
 			/**
-			 * Filter the URL to redirect to when Press This saves.
+			 * Filters the URL to redirect to when Press This saves.
 			 *
 			 * @since 4.2.0
 			 *
@@ -185,7 +196,7 @@ class WP_Press_This {
 			 * @param int    $post_id Post ID.
 			 * @param string $status  Post status.
 			 */
-			$redirect = apply_filters( 'press_this_save_redirect', $redirect, $post_id, $post['post_status'] );
+			$redirect = apply_filters( 'press_this_save_redirect', $redirect, $post_id, $post_data['post_status'] );
 
 			if ( $redirect ) {
 				wp_send_json_success( array( 'redirect' => $redirect, 'force' => $forceRedirect ) );
@@ -196,7 +207,7 @@ class WP_Press_This {
 	}
 
 	/**
-	 * AJAX handler for adding a new category.
+	 * Ajax handler for adding a new category.
 	 *
 	 * @since 4.2.0
 	 * @access public
@@ -290,7 +301,7 @@ class WP_Press_This {
 			return $remote_url;
 		}
 
-		$useful_html_elements = array(
+		$allowed_elements = array(
 			'img' => array(
 				'src'      => true,
 				'width'    => true,
@@ -312,7 +323,7 @@ class WP_Press_This {
 		);
 
 		$source_content = wp_remote_retrieve_body( $remote_url );
-		$source_content = wp_kses( $source_content, $useful_html_elements );
+		$source_content = wp_kses( $source_content, $allowed_elements );
 
 		return $source_content;
 	}
@@ -387,7 +398,7 @@ class WP_Press_This {
 			return ''; // Return empty rather than a truncated/invalid URL
 		}
 
-		// Does not look like an URL.
+		// Does not look like a URL.
 		if ( ! preg_match( '/^([!#$&-;=?-\[\]_a-z~]|%[0-9a-fA-F]{2})+$/', $url ) ) {
 			return '';
 		}
@@ -698,7 +709,7 @@ class WP_Press_This {
 		}
 
 		/**
-		 * Filter whether to enable in-source media discovery in Press This.
+		 * Filters whether to enable in-source media discovery in Press This.
 		 *
 		 * @since 4.2.0
 		 *
@@ -710,11 +721,7 @@ class WP_Press_This {
 			 * making PT fully backward compatible with the older bookmarklet.
 			 */
 			if ( empty( $_POST ) && ! empty( $data['u'] ) ) {
-				if ( isset( $_GET['_wpnonce'] ) && wp_verify_nonce( $_GET['_wpnonce'], 'scan-site' ) ) {
-					$data = $this->source_data_fetch_fallback( $data['u'], $data );
-				} else {
-					$data['errors'] = 'missing nonce';
-				}
+				$data = $this->source_data_fetch_fallback( $data['u'], $data );
 			} else {
 				foreach ( array( '_images', '_embeds' ) as $type ) {
 					if ( empty( $_POST[ $type ] ) ) {
@@ -777,7 +784,7 @@ class WP_Press_This {
 		}
 
 		/**
-		 * Filter the Press This data array.
+		 * Filters the Press This data array.
 		 *
 		 * @since 4.2.0
 		 *
@@ -805,36 +812,7 @@ class WP_Press_This {
 			$press_this = str_replace( '.css', '-rtl.css', $press_this );
 		}
 
-		$open_sans_font_url = '';
-
-		/* translators: If there are characters in your language that are not supported
-		 * by Open Sans, translate this to 'off'. Do not translate into your own language.
-		 */
-		if ( 'off' !== _x( 'on', 'Open Sans font: on or off' ) ) {
-			$subsets = 'latin,latin-ext';
-
-			/* translators: To add an additional Open Sans character subset specific to your language,
-			 * translate this to 'greek', 'cyrillic' or 'vietnamese'. Do not translate into your own language.
-			 */
-			$subset = _x( 'no-subset', 'Open Sans font: add new subset (greek, cyrillic, vietnamese)' );
-
-			if ( 'cyrillic' == $subset ) {
-				$subsets .= ',cyrillic,cyrillic-ext';
-			} elseif ( 'greek' == $subset ) {
-				$subsets .= ',greek,greek-ext';
-			} elseif ( 'vietnamese' == $subset ) {
-				$subsets .= ',vietnamese';
-			}
-
-			$query_args = array(
-				'family' => urlencode( 'Open Sans:400italic,700italic,400,600,700' ),
-				'subset' => urlencode( $subsets ),
-			);
-
-			$open_sans_font_url = ',' . add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
-		}
-
-		return $styles . $press_this . $open_sans_font_url;
+		return $styles . $press_this;
 	}
 
 	/**
@@ -1189,12 +1167,17 @@ class WP_Press_This {
 		}
 
 		/**
-		 * Filter the default HTML for the Press This editor.
+		 * Filters the default HTML tags used in the suggested content for the editor.
+		 *
+		 * The HTML strings use printf format. After filtering the content is added at the specified places with `sprintf()`.
 		 *
 		 * @since 4.2.0
 		 *
-		 * @param array $default_html Associative array with two keys: 'quote' where %1$s is replaced with the site description
-		 *                            or the selected content, and 'link' there %1$s is link href, %2$s is link text.
+		 * @param array $default_html Associative array with three possible keys:
+		 *                                - 'quote' where %1$s is replaced with the site description or the selected content.
+		 *                                - 'link' where %1$s is link href, %2$s is link text, usually the source page title.
+		 *                                - 'embed' which contains an [embed] shortcode when the source page offers embeddable content.
+		 * @param array $data         Associative array containing the data from the source page.
 		 */
 		$default_html = apply_filters( 'press_this_suggested_html', $default_html, $data );
 
@@ -1254,7 +1237,7 @@ class WP_Press_This {
 		$site_data = array(
 			'v' => ! empty( $data['v'] ) ? $data['v'] : '',
 			'u' => ! empty( $data['u'] ) ? $data['u'] : '',
-			'hasData' => ! empty( $data ) && ! isset( $data['errors'] ),
+			'hasData' => ! empty( $data ),
 		);
 
 		if ( ! empty( $images ) ) {
@@ -1386,9 +1369,8 @@ class WP_Press_This {
 	<div id="scanbar" class="scan">
 		<form method="GET">
 			<label for="url-scan" class="screen-reader-text"><?php _e( 'Scan site for content' ); ?></label>
-			<input type="url" name="u" id="url-scan" class="scan-url" value="<?php echo esc_attr( $site_data['u'] ) ?>" placeholder="<?php esc_attr_e( 'Enter a URL to scan' ) ?>" />
+			<input type="url" name="u" id="url-scan" class="scan-url" value="" placeholder="<?php esc_attr_e( 'Enter a URL to scan' ) ?>" />
 			<input type="submit" name="url-scan-submit" id="url-scan-submit" class="scan-submit" value="<?php esc_attr_e( 'Scan' ) ?>" />
-			<?php wp_nonce_field( 'scan-site' ); ?>
 		</form>
 	</div>
 
@@ -1558,6 +1540,9 @@ class WP_Press_This {
 	/** This action is documented in wp-admin/admin-footer.php */
 	do_action( 'admin_footer' );
 
+	/** This action is documented in wp-admin/admin-footer.php */
+	do_action( 'admin_print_footer_scripts-press-this.php' );
+
 	/** This action is documented in wp-admin/admin-footer.php */
 	do_action( 'admin_print_footer_scripts' );
 
